@@ -112,6 +112,41 @@ layout_foreach_cb(gpointer data, gpointer user_data)
 }
 
 
+//If is third part im. Use their own config-UI
+int fcitx_im_config_thirdpart(FcitxConfigFileDesc *cdesc)
+{
+    char* comd = NULL;
+    char* para = NULL;
+    if(cdesc == NULL) {
+        return 0;
+    }
+    HASH_FOREACH(groupdesc, cdesc->groupsDesc, FcitxConfigGroupDesc) {
+        HASH_FOREACH(optiondesc, groupdesc->optionsDesc, FcitxConfigOptionDesc) {
+            if (optiondesc->desc && strlen(optiondesc->desc) != 0) {
+                if (0 == strcmp(optiondesc->optionName, "Setting") && 10 == optiondesc->type) {
+                    //printf("%s:%d\tDONE! [%s]\n", __FILE__, __LINE__, optiondesc->rawDefaultValue);
+                    comd = optiondesc->rawDefaultValue;
+                }
+                if (0 == strcmp(optiondesc->optionName, "Parameter") && 2 == optiondesc->type) {
+                    printf("%s:%d\tDONE! [%s]\n", __FILE__, __LINE__, optiondesc->rawDefaultValue);
+                    para = optiondesc->rawDefaultValue;
+                    if((NULL != comd) && (0 == strcmp("",para))){
+                        char*args[] = {comd,NULL};
+                        fcitx_utils_start_process(args);
+                        return 1;
+                    } else if((NULL != comd)&&(NULL != para)) {
+                        printf("%s:%d\tDONE! [%s][%s]\n", __FILE__, __LINE__, comd , para);
+                        char*args[] = {comd,para,NULL};
+                        fcitx_utils_start_process(args);
+                        return 1;
+                    }
+                }
+            }
+        }
+    }
+    return 0;
+}
+
 GtkWidget* fcitx_im_config_dialog_new(GtkWindow* parent, FcitxAddon* addon, gchar* imname)
 {
     FcitxImConfigDialog* self =
@@ -139,6 +174,10 @@ GtkWidget* fcitx_im_config_dialog_new(GtkWindow* parent, FcitxAddon* addon, gcha
         configurable = (gboolean)(cfdesc != NULL || strlen(addon->subconfig) != 0);
     }
 
+    if (NULL != cfdesc && fcitx_im_config_thirdpart(cfdesc)) {
+        return NULL;
+    }
+
     do {
 
         if (strncmp(imname, "fcitx-keyboard", strlen("fcitx-keyboard")) == 0)
